EventFilter

Struct EventFilter 

pub struct EventFilter {
    pub contract_address: Option<Address>,
    pub event: Option<String>,
}

Fields

contract_address: Option<Address>

Contract address to filter events from. If None, events from all contracts will be tracked.

event: Option<String>

Human-readable event signature, e.g. “Transfer(address,address,uint256)”. If None, all events from the specified contract(s) will be tracked.

Implementations

Source

impl EventFilter

pub fn new() -> Self

Creates a new EventFilter.

Examples
use alloy::primitives::Address;
use event_scanner::EventFilter;

pub async fn create_event_filter() -> EventFilter {
    let contract_address = Address::ZERO;
    let filter = EventFilter::new()
        .with_contract_address(contract_address)
        .with_event("Transfer(address,address,uint256)");

    filter
}
pub fn with_contract_address(self, contract_address: Address) -> Self

Sets the contract address to filter events from. If not set, events from all contracts will be tracked.

pub fn with_event<E: Into<String>>(self, event: E) -> Self

Sets the event signature to filter specific events. If not set, all events from the specified contract(s) will be tracked.