pub struct SyncFromLatestEvents { /* private fields */ }Expand description
Mode marker for scanning by syncing from the specified count of latest events and then switching to live mode.
For more details on this scanner mode, see
EventScannerBuilder::sync().from_latest(count).