Type Alias Message
Source pub type Message = ScannerMessage<Vec<Log>>;
The item type yielded by event subscription streams.
This is a ScannerMessage whose data payload is a batch of Log values.
pub enum Message {
Data(Vec<Log>),
Notification(Notification),
}
Data streamed to the subscriber.
Notification about scanner state changes or important events.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.