pub struct EventFilter { /* private fields */ }Expand description
Type representing filters to apply when fetching events from the chain.
Examples
use alloy::primitives::address;
use event_scanner::EventFilter;
pub async fn create_event_filter() -> EventFilter {
let contract_address = address!("0xd8dA6BF26964af9d7eed9e03e53415d37aa96045");
let filter = EventFilter::new()
.contract_address(contract_address)
.event("Transfer(address,address,uint256)");
filter
}Implementations
Sourceimpl EventFilter
impl EventFilter
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new EventFilter.
Sourcepub fn contract_address(self, contract_address: impl Into<Address>) -> Self
pub fn contract_address(self, contract_address: impl Into<Address>) -> Self
Sets the contract address to filter events from. If not set, events from all contracts will be tracked.
Sourcepub fn contract_addresses(
self,
contract_addresses: impl IntoIterator<Item = impl Into<Address>>,
) -> Self
pub fn contract_addresses( self, contract_addresses: impl IntoIterator<Item = impl Into<Address>>, ) -> Self
Sets the contract address to filter events from. If not set, events from all contracts will be tracked.
Sourcepub fn event(self, event: impl Into<String>) -> Self
pub fn event(self, event: impl Into<String>) -> Self
Sets the event signature to filter specific events. If neither events nor event signature hashes are set, all events from the specified contract(s) will be tracked.
Sourcepub fn events(self, events: impl IntoIterator<Item = impl Into<String>>) -> Self
pub fn events(self, events: impl IntoIterator<Item = impl Into<String>>) -> Self
Sets the event signatures to filter specific events. If neither events nor event signature hashes are set, all events from the specified contract(s) will be tracked.
Sourcepub fn event_signature(self, event_signature: impl Into<Topic>) -> Self
pub fn event_signature(self, event_signature: impl Into<Topic>) -> Self
Sets the event signature hash to filter specific events. If neither event signature hashes nor events are set, all events from the specified contract(s) will be tracked.
Sourcepub fn event_signatures(
self,
event_signatures: impl IntoIterator<Item = impl Into<Topic>>,
) -> Self
pub fn event_signatures( self, event_signatures: impl IntoIterator<Item = impl Into<Topic>>, ) -> Self
Sets the event signature hashes to filter specific events. If neither event signature hashes nor events are set, all events from the specified contract(s) will be tracked.