pub struct EventScanner<M = Unspecified, N: Network = Ethereum> { /* private fields */ }Implementations
Sourceimpl<N: Network> EventScanner<Historic, N>
impl<N: Network> EventScanner<Historic, N>
Sourcepub async fn start(self) -> Result<(), ScannerError>
pub async fn start(self) -> Result<(), ScannerError>
Starts the scanner.
Important notes
- Register event streams via
scanner.subscribe(filter)before calling this function. - The method returns immediately; events are delivered asynchronously.
Errors
Can error out if the service fails to start.
Sourceimpl<N: Network> EventScanner<LatestEvents, N>
impl<N: Network> EventScanner<LatestEvents, N>
Sourcepub async fn start(self) -> Result<(), ScannerError>
pub async fn start(self) -> Result<(), ScannerError>
Starts the scanner.
Important notes
- Register event streams via
scanner.subscribe(filter)before calling this function. - The method returns immediately; events are delivered asynchronously.
Errors
Can error out if the service fails to start.
Sourceimpl<N: Network> EventScanner<Live, N>
impl<N: Network> EventScanner<Live, N>
Sourcepub async fn start(self) -> Result<(), ScannerError>
pub async fn start(self) -> Result<(), ScannerError>
Starts the scanner.
Important notes
- Register event streams via
scanner.subscribe(filter)before calling this function. - The method returns immediately; events are delivered asynchronously.
Errors
Can error out if the service fails to start.
Sourceimpl<N: Network> EventScanner<SyncFromBlock, N>
impl<N: Network> EventScanner<SyncFromBlock, N>
Sourcepub async fn start(self) -> Result<(), ScannerError>
pub async fn start(self) -> Result<(), ScannerError>
Starts the scanner.
Important notes
- Register event streams via
scanner.subscribe(filter)before calling this function. - The method returns immediately; events are delivered asynchronously.
Errors
Can error out if the service fails to start.
Sourceimpl<N: Network> EventScanner<SyncFromLatestEvents, N>
impl<N: Network> EventScanner<SyncFromLatestEvents, N>
Sourcepub async fn start(self) -> Result<(), ScannerError>
pub async fn start(self) -> Result<(), ScannerError>
Starts the scanner.
Important notes
- Register event streams via
scanner.subscribe(filter)before calling this function. - The method returns immediately; events are delivered asynchronously.
Errors
Can error out if the service fails to start.
Sourceimpl<M, N: Network> EventScanner<M, N>
impl<M, N: Network> EventScanner<M, N>
pub fn subscribe( &mut self, filter: EventFilter, ) -> ReceiverStream<EventScannerResult>